import pyfiglet
import textwrap


FONT_STYLES = {
    "bold": {
        "a": "𝗮", "b": "𝗯", "c": "𝗰", "d": "𝗱", "e": "𝗲", "f": "𝗳", "g": "𝗴", "h": "𝗵", "i": "𝗶", "j": "𝗷",
        "k": "𝗸", "l": "𝗹", "m": "𝗺", "n": "𝗻", "o": "𝗼", "p": "𝗽", "q": "𝗾", "r": "𝗿", "s": "𝘀", "t": "𝘁",
        "u": "𝘂", "v": "𝘃", "w": "𝘄", "x": "𝘅", "y": "𝘆", "z": "𝘇",
        "A": "𝗔", "B": "𝗕", "C": "𝗖", "D": "𝗗", "E": "𝗘", "F": "𝗙", "G": "𝗚", "H": "𝗛", "I": "𝗜", "J": "𝗝",
        "K": "𝗞", "L": "𝗟", "M": "𝗠", "N": "𝗡", "O": "𝗢", "P": "𝗣", "Q": "𝗤", "R": "𝗥", "S": "𝗦", "T": "𝗧",
        "U": "𝗨", "V": "𝗩", "W": "𝗪", "X": "𝗫", "Y": "𝗬", "Z": "𝗭",
        "0": "𝟬", "1": "𝟭", "2": "𝟮", "3": "𝟯", "4": "𝟰", "5": "𝟱", "6": "𝟲", "7": "𝟳", "8": "𝟴", "9": "𝟵",
    },

    "italic": {
        "a": "𝘢", "b": "𝘣", "c": "𝘤", "d": "𝘥", "e": "𝘦", "f": "𝘧", "g": "𝘨", "h": "𝘩", "i": "𝘪", "j": "𝘫",
        "k": "𝘬", "l": "𝘭", "m": "𝘮", "n": "𝘯", "o": "𝘰", "p": "𝘱", "q": "𝘲", "r": "𝘳", "s": "𝘴", "t": "𝘵",
        "u": "𝘶", "v": "𝘷", "w": "𝘸", "x": "𝘹", "y": "𝘺", "z": "𝘻",
        "A": "𝘈", "B": "𝘉", "C": "𝘊", "D": "𝘋", "E": "𝘌", "F": "𝘍", "G": "𝘎", "H": "𝘏", "I": "𝘐", "J": "𝘑",
        "K": "𝘒", "L": "𝘓", "M": "𝘔", "N": "𝘕", "O": "𝘖", "P": "𝘗", "Q": "𝘘", "R": "𝘙", "S": "𝘚", "T": "𝘛",
        "U": "𝘜", "V": "𝘝", "W": "𝘞", "X": "𝘟", "Y": "𝘠", "Z": "𝘡",
    },

    "cursive": {
        "a": "𝓪", "b": "𝓫", "c": "𝓬", "d": "𝓭", "e": "𝓮", "f": "𝓯", "g": "𝓰", "h": "𝓱", "i": "𝓲", "j": "𝓳",
        "k": "𝓴", "l": "𝓵", "m": "𝓶", "n": "𝓷", "o": "𝓸", "p": "𝓹", "q": "𝓺", "r": "𝓻", "s": "𝓼", "t": "𝓽",
        "u": "𝓾", "v": "𝓿", "w": "𝔀", "x": "𝔁", "y": "𝔂", "z": "𝔃",
        "A": "𝓐", "B": "𝓑", "C": "𝓒", "D": "𝓓", "E": "𝓔", "F": "𝓕", "G": "𝓖", "H": "𝓗", "I": "𝓘", "J": "𝓙",
        "K": "𝓚", "L": "𝓛", "M": "𝓜", "N": "𝓝", "O": "𝓞", "P": "𝓟", "Q": "𝓠", "R": "𝓡", "S": "𝓢", "T": "𝓣",
        "U": "𝓤", "V": "𝓥", "W": "𝓦", "X": "𝓧", "Y": "𝓨", "Z": "𝓩",
    },

    "script": {
            'a': '𝒶', 'b': '𝒷', 'c': '𝒸', 'd': '𝒹', 'e': 'ℯ', 'f': '𝒻', 'g': 'ℊ', 'h': '𝒽', 'i': '𝒾', 'j': '𝒿',
            'k': '𝓀', 'l': '𝓁', 'm': '𝓂', 'n': '𝓃', 'o': 'ℴ', 'p': '𝓅', 'q': '𝓆', 'r': '𝓇', 's': '𝓈', 't': '𝓉',
            'u': '𝓊', 'v': '𝓋', 'w': '𝓌', 'x': '𝓍', 'y': '𝓎', 'z': '𝓏',
            'A': '𝒜', 'B': 'ℬ', 'C': '𝒞', 'D': '𝒟', 'E': 'ℰ', 'F': 'ℱ', 'G': '𝒢', 'H': 'ℋ', 'I': 'ℐ', 'J': '𝒥',
            'K': '𝒦', 'L': 'ℒ', 'M': 'ℳ', 'N': '𝒩', 'O': '𝒪', 'P': '𝒫', 'Q': '𝒬', 'R': 'ℛ', 'S': '𝒮', 'T': '𝒯',
            'U': '𝒰', 'V': '𝒱', 'W': '𝒲', 'X': '𝒳', 'Y': '𝒴', 'Z': '𝒵'
        },
    
    "fraktur": {
            'a': '𝔞', 'b': '𝔟', 'c': '𝔠', 'd': '𝔡', 'e': '𝔢', 'f': '𝔣', 'g': '𝔤', 'h': '𝔥', 'i': '𝔦', 'j': '𝔧',
            'k': '𝔨', 'l': '𝔩', 'm': '𝔪', 'n': '𝔫', 'o': '𝔬', 'p': '𝔭', 'q': '𝔮', 'r': '𝔯', 's': '𝔰', 't': '𝔱',
            'u': '𝔲', 'v': '𝔳', 'w': '𝔴', 'x': '𝔵', 'y': '𝔶', 'z': '𝔷',
            'A': '𝔄', 'B': '𝔅', 'C': 'ℭ', 'D': '𝔇', 'E': '𝔈', 'F': '𝔉', 'G': '𝔊', 'H': 'ℌ', 'I': 'ℑ', 'J': '𝔍',
            'K': '𝔎', 'L': '𝔏', 'M': '𝔐', 'N': '𝔑', 'O': '𝔒', 'P': '𝔓', 'Q': '𝔔', 'R': 'ℜ', 'S': '𝔖', 'T': '𝔗',
            'U': '𝔘', 'V': '𝔙', 'W': '𝔚', 'X': '𝔛', 'Y': '𝔜', 'Z': 'ℨ'
        },


    "monospace": {
        "a": "𝚊", "b": "𝚋", "c": "𝚌", "d": "𝚍", "e": "𝚎", "f": "𝚏", "g": "𝚐", "h": "𝚑", "i": "𝚒", "j": "𝚓",
        "k": "𝚔", "l": "𝚕", "m": "𝚖", "n": "𝚗", "o": "𝚘", "p": "𝚙", "q": "𝚚", "r": "𝚛", "s": "𝚜", "t": "𝚝",
        "u": "𝚞", "v": "𝚟", "w": "𝚠", "x": "𝚡", "y": "𝚢", "z": "𝚣",
        "A": "𝙰", "B": "𝙱", "C": "𝙲", "D": "𝙳", "E": "𝙴", "F": "𝙵", "G": "𝙶", "H": "𝙷", "I": "𝙸", "J": "𝙹",
        "K": "𝙺", "L": "𝙻", "M": "𝙼", "N": "𝙽", "O": "𝙾", "P": "𝙿", "Q": "𝚀", "R": "𝚁", "S": "𝚂", "T": "𝚃",
        "U": "𝚄", "V": "𝚅", "W": "𝚆", "X": "𝚇", "Y": "𝚈", "Z": "𝚉",
        "0": "𝟶", "1": "𝟷", "2": "𝟸", "3": "𝟹", "4": "𝟺", "5": "𝟻", "6": "𝟼", "7": "𝟽", "8": "𝟾", "9": "𝟿",
    },

    "double_struck": {
        "a": "𝕒", "b": "𝕓", "c": "𝕔", "d": "𝕕", "e": "𝕖", "f": "𝕗", "g": "𝕘", "h": "𝕙", "i": "𝕚", "j": "𝕛",
        "k": "𝕜", "l": "𝕝", "m": "𝕞", "n": "𝕟", "o": "𝕠", "p": "𝕡", "q": "𝕢", "r": "𝕣", "s": "𝕤", "t": "𝕥",
        "u": "𝕦", "v": "𝕧", "w": "𝕨", "x": "𝕩", "y": "𝕪", "z": "𝕫",
        "A": "𝔸", "B": "𝔹", "C": "ℂ", "D": "𝔻", "E": "𝔼", "F": "𝔽", "G": "𝔾", "H": "ℍ", "I": "𝕀", "J": "𝕁",
        "K": "𝕂", "L": "𝕃", "M": "𝕄", "N": "ℕ", "O": "𝕆", "P": "ℙ", "Q": "ℚ", "R": "ℝ", "S": "𝕊", "T": "𝕋",
        "U": "𝕌", "V": "𝕍", "W": "𝕎", "X": "𝕏", "Y": "𝕐", "Z": "ℤ",
        "0": "𝟘", "1": "𝟙", "2": "𝟚", "3": "𝟛", "4": "𝟜", "5": "𝟝", "6": "𝟞", "7": "𝟟", "8": "𝟠", "9": "𝟡",
    },

    "small_caps": {
        "a": "ᴀ", "b": "ʙ", "c": "ᴄ", "d": "ᴅ", "e": "ᴇ", "f": "ғ", "g": "ɢ", "h": "ʜ", "i": "ɪ", "j": "ᴊ",
        "k": "ᴋ", "l": "ʟ", "m": "ᴍ", "n": "ɴ", "o": "ᴏ", "p": "ᴘ", "q": "ǫ", "r": "ʀ", "s": "s", "t": "ᴛ",
        "u": "ᴜ", "v": "ᴠ", "w": "ᴡ", "x": "x", "y": "ʏ", "z": "ᴢ",
    },

    "circled": {
        "a": "ⓐ", "b": "ⓑ", "c": "ⓒ", "d": "ⓓ", "e": "ⓔ", "f": "ⓕ", "g": "ⓖ", "h": "ⓗ", "i": "ⓘ", "j": "ⓙ",
        "k": "ⓚ", "l": "ⓛ", "m": "ⓜ", "n": "ⓝ", "o": "ⓞ", "p": "ⓟ", "q": "ⓠ", "r": "ⓡ", "s": "ⓢ", "t": "ⓣ",
        "u": "ⓤ", "v": "ⓥ", "w": "ⓦ", "x": "ⓧ", "y": "ⓨ", "z": "ⓩ",
        "A": "Ⓐ", "B": "Ⓑ", "C": "Ⓒ", "D": "Ⓓ", "E": "Ⓔ", "F": "Ⓕ", "G": "Ⓖ", "H": "Ⓗ", "I": "Ⓘ", "J": "Ⓙ",
        "K": "Ⓚ", "L": "Ⓛ", "M": "Ⓜ", "N": "Ⓝ", "O": "Ⓞ", "P": "Ⓟ", "Q": "Ⓠ", "R": "Ⓡ", "S": "Ⓢ", "T": "Ⓣ",
        "U": "Ⓤ", "V": "Ⓥ", "W": "Ⓦ", "X": "Ⓧ", "Y": "Ⓨ", "Z": "Ⓩ",
        "0": "⓪", "1": "①", "2": "②", "3": "③", "4": "④", "5": "⑤", "6": "⑥", "7": "⑦", "8": "⑧", "9": "⑨",
    },

    "circled_filled": {
        "a": "🅐", "b": "🅑", "c": "🅒", "d": "🅓", "e": "🅔", "f": "🅕", "g": "🅖", "h": "🅗", "i": "🅘", "j": "🅙",
        "k": "🅚", "l": "🅛", "m": "🅜", "n": "🅝", "o": "🅞", "p": "🅟", "q": "🅠", "r": "🅡", "s": "🅢", "t": "🅣",
        "u": "🅤", "v": "🅥", "w": "🅦", "x": "🅧", "y": "🅨", "z": "🅩",
        "A": "🅐", "B": "🅑", "C": "🅒", "D": "🅓", "E": "🅔", "F": "🅕", "G": "🅖", "H": "🅗", "I": "🅘", "J": "🅙",
        "K": "🅚", "L": "🅛", "M": "🅜", "N": "🅝", "O": "🅞", "P": "🅟", "Q": "🅠", "R": "🅡", "S": "🅢", "T": "🅣",
        "U": "🅤", "V": "🅥", "W": "🅦", "X": "🅧", "Y": "🅨", "Z": "🅩",
        "0": "⓿", "1": "❶", "2": "❷", "3": "❸", "4": "❹", "5": "❺", "6": "❻", "7": "❼", "8": "❽", "9": "❾",
    },

    "inverted": {
        "a": "ɐ", "b": "q", "c": "ɔ", "d": "p", "e": "ǝ", "f": "ɟ", "g": "ɓ", "h": "ɥ", "i": "ı", "j": "ɾ",
        "k": "ʞ", "l": "l", "m": "ɯ", "n": "u", "o": "o", "p": "d", "q": "b", "r": "ɹ", "s": "s", "t": "ʇ",
        "u": "n", "v": "ʌ", "w": "ʍ", "x": "x", "y": "ʎ", "z": "z",
        "A": "∀", "B": "𐐒", "C": "Ↄ", "D": "◖", "E": "Ǝ", "F": "Ⅎ", "G": "⅁", "H": "H", "I": "I", "J": "ſ",
        "K": "ʞ", "L": "⅂", "M": "W", "N": "N", "O": "O", "P": "Ԁ", "Q": "Ό", "R": "ᴚ", "S": "S", "T": "⊥",
        "U": "∩", "V": "Λ", "W": "M", "X": "X", "Y": "⅄", "Z": "Z",
    },

    "squared": {
        "a": "🄰", "b": "🄱", "c": "🄲", "d": "🄳", "e": "🄴", "f": "🄵", "g": "🄶", "h": "🄷", "i": "🄸", "j": "🄹",
        "k": "🄺", "l": "🄻", "m": "🄼", "n": "🄽", "o": "🄾", "p": "🄿", "q": "🅀", "r": "🅁", "s": "🅂", "t": "🅃",
        "u": "🅄", "v": "🅅", "w": "🅆", "x": "🅇", "y": "🅈", "z": "🅉",
        "A": "🄰", "B": "🄱", "C": "🄲", "D": "🄳", "E": "🄴", "F": "🄵", "G": "🄶", "H": "🄷", "I": "🄸", "J": "🄹",
        "K": "🄺", "L": "🄻", "M": "🄼", "N": "🄽", "O": "🄾", "P": "🄿", "Q": "🅀", "R": "🅁", "S": "🅂", "T": "🅃",
        "U": "🅄", "V": "🅅", "W": "🅆", "X": "🅇", "Y": "🅈", "Z": "🅉",
        "0": "0", "1": "1", "2": "2", "3": "3", "4": "4", "5": "5", "6": "6", "7": "7", "8": "8", "9": "9",
    },

    "squared_filled": {
        "a": "🅰", "b": "🅱", "c": "🅲", "d": "🅳", "e": "🅴", "f": "🅵", "g": "🅶", "h": "🅷", "i": "🅸", "j": "🅹",
        "k": "🅺", "l": "🅻", "m": "🅼", "n": "🅽", "o": "🅾", "p": "🅿", "q": "🆀", "r": "🆁", "s": "🆂", "t": "🆃",
        "u": "🆄", "v": "🆅", "w": "🆆", "x": "🆇", "y": "🆈", "z": "🆉",
        "A": "🅰", "B": "🅱", "C": "🅲", "D": "🅳", "E": "🅴", "F": "🅵", "G": "🅶", "H": "🅷", "I": "🅸", "J": "🅹",
        "K": "🅺", "L": "🅻", "M": "🅼", "N": "🅽", "O": "🅾", "P": "🅿", "Q": "🆀", "R": "🆁", "S": "🆂", "T": "🆃",
        "U": "🆄", "V": "🆅", "W": "🆆", "X": "🆇", "Y": "🆈", "Z": "🆉",
        "0": "0", "1": "1", "2": "2", "3": "3", "4": "4", "5": "5", "6": "6", "7": "7", "8": "8", "9": "9",
    },

    "parenthesized": {
        "a": "⒜", "b": "⒝", "c": "⒞", "d": "⒟", "e": "⒠", "f": "⒡", "g": "⒢", "h": "⒣", "i": "⒤", "j": "⒥",
        "k": "⒦", "l": "⒧", "m": "⒨", "n": "⒩", "o": "⒪", "p": "⒫", "q": "⒬", "r": "⒭", "s": "⒮", "t": "⒯",
        "u": "⒰", "v": "⒱", "w": "⒲", "x": "⒳", "y": "⒴", "z": "⒵",
        "A": "⒜", "B": "⒝", "C": "⒞", "D": "⒟", "E": "⒠", "F": "⒡", "G": "⒢", "H": "⒣", "I": "⒤", "J": "⒥",
        "K": "⒦", "L": "⒧", "M": "⒨", "N": "⒩", "O": "⒪", "P": "⒫", "Q": "⒬", "R": "⒭", "S": "⒮", "T": "⒯",
        "U": "⒰", "V": "⒱", "W": "⒲", "X": "⒳", "Y": "⒴", "Z": "⒵",
        "0": "0", "1": "1", "2": "2", "3": "3", "4": "4", "5": "5", "6": "6", "7": "7", "8": "8", "9": "9",
    },

    "fullwidth": {
        "a": "ａ", "b": "ｂ", "c": "ｃ", "d": "ｄ", "e": "ｅ", "f": "ｆ", "g": "ｇ", "h": "ｈ", "i": "ｉ", "j": "ｊ",
        "k": "ｋ", "l": "ｌ", "m": "ｍ", "n": "ｎ", "o": "ｏ", "p": "ｐ", "q": "ｑ", "r": "ｒ", "s": "ｓ", "t": "ｔ",
        "u": "ｕ", "v": "ｖ", "w": "ｗ", "x": "ｘ", "y": "ｙ", "z": "ｚ",
        "A": "Ａ", "B": "Ｂ", "C": "Ｃ", "D": "Ｄ", "E": "Ｅ", "F": "Ｆ", "G": "Ｇ", "H": "Ｈ", "I": "Ｉ", "J": "Ｊ",
        "K": "Ｋ", "L": "Ｌ", "M": "Ｍ", "N": "Ｎ", "O": "Ｏ", "P": "Ｐ", "Q": "Ｑ", "R": "Ｒ", "S": "Ｓ", "T": "Ｔ",
        "U": "Ｕ", "V": "Ｖ", "W": "Ｗ", "X": "Ｘ", "Y": "Ｙ", "Z": "Ｚ",
        "0": "０", "1": "１", "2": "２", "3": "３", "4": "４", "5": "５", "6": "６", "7": "７", "8": "８", "9": "９",
    },

    "superscript": {
        "a": "ᵃ", "b": "ᵇ", "c": "ᶜ", "d": "ᵈ", "e": "ᵉ", "f": "ᶠ", "g": "ᵍ", "h": "ʰ", "i": "ⁱ", "j": "ʲ",
        "k": "ᵏ", "l": "ˡ", "m": "ᵐ", "n": "ⁿ", "o": "ᵒ", "p": "ᵖ", "q": "ᑫ", "r": "ʳ", "s": "ˢ", "t": "ᵗ",
        "u": "ᵘ", "v": "ᵛ", "w": "ʷ", "x": "ˣ", "y": "ʸ", "z": "ᶻ",
        "A": "ᴬ", "B": "ᴮ", "C": "ᶜ", "D": "ᴰ", "E": "ᴱ", "F": "ᶠ", "G": "ᴳ", "H": "ᴴ", "I": "ᴵ", "J": "ᴶ",
        "K": "ᴷ", "L": "ᴸ", "M": "ᴹ", "N": "ᴺ", "O": "ᴼ", "P": "ᴾ", "Q": "ᑫ", "R": "ᴿ", "S": "ˢ", "T": "ᵀ",
        "U": "ᵁ", "V": "ⱽ", "W": "ᵂ", "X": "ˣ", "Y": "ʸ", "Z": "ᶻ",
        "0": "⁰", "1": "¹", "2": "²", "3": "³", "4": "⁴", "5": "⁵", "6": "⁶", "7": "⁷", "8": "⁸", "9": "⁹",
    },

    "subscript": {
        "a": "ₐ", "b": "ᵦ", "c": "𝒸", "d": "𝒹", "e": "ₑ", "f": "𝒻", "g": "𝓰", "h": "ₕ", "i": "ᵢ", "j": "ⱼ",
        "k": "ₖ", "l": "ₗ", "m": "ₘ", "n": "ₙ", "o": "ₒ", "p": "ₚ", "q": "ᑫ", "r": "ᵣ", "s": "ₛ", "t": "ₜ",
        "u": "ᵤ", "v": "ᵥ", "w": "𝓌", "x": "ₓ", "y": "ᵧ", "z": "𝓏",
        "A": "ₐ", "B": "ᵦ", "C": "𝒸", "D": "𝒹", "E": "ₑ", "F": "𝒻", "G": "𝓰", "H": "ₕ", "I": "ᵢ", "J": "ⱼ",
        "K": "ₖ", "L": "ₗ", "M": "ₘ", "N": "ₙ", "O": "ₒ", "P": "ₚ", "Q": "ᑫ", "R": "ᵣ", "S": "ₛ", "T": "ₜ",
        "U": "ᵤ", "V": "ᵥ", "W": "𝓌", "X": "ₓ", "Y": "ᵧ", "Z": "𝓏",
        "0": "₀", "1": "₁", "2": "₂", "3": "₃", "4": "₄", "5": "₅", "6": "₆", "7": "₇", "8": "₈", "9": "₉",
    },

    "strikethrough": {
        "a": "a̶", "b": "b̶", "c": "c̶", "d": "d̶", "e": "e̶", "f": "f̶", "g": "g̶", "h": "h̶", "i": "i̶", "j": "j̶",
        "k": "k̶", "l": "l̶", "m": "m̶", "n": "n̶", "o": "o̶", "p": "p̶", "q": "q̶", "r": "r̶", "s": "s̶", "t": "t̶",
        "u": "u̶", "v": "v̶", "w": "w̶", "x": "x̶", "y": "y̶", "z": "z̶",
        "A": "A̶", "B": "B̶", "C": "C̶", "D": "D̶", "E": "E̶", "F": "F̶", "G": "G̶", "H": "H̶", "I": "I̶", "J": "J̶",
        "K": "K̶", "L": "L̶", "M": "M̶", "N": "N̶", "O": "O̶", "P": "P̶", "Q": "Q̶", "R": "R̶", "S": "S̶", "T": "T̶",
        "U": "U̶", "V": "V̶", "W": "W̶", "X": "X̶", "Y": "Y̶", "Z": "Z̶",
        "0": "0̶", "1": "1̶", "2": "2̶", "3": "3̶", "4": "4̶", "5": "5̶", "6": "6̶", "7": "7̶", "8": "8̶", "9": "9̶",
    },

    "underline": {
        "a": "a̲", "b": "b̲", "c": "c̲", "d": "d̲", "e": "e̲", "f": "f̲", "g": "g̲", "h": "h̲", "i": "i̲", "j": "j̲",
        "k": "k̲", "l": "l̲", "m": "m̲", "n": "n̲", "o": "o̲", "p": "p̲", "q": "q̲", "r": "r̲", "s": "s̲", "t": "t̲",
        "u": "u̲", "v": "v̲", "w": "w̲", "x": "x̲", "y": "y̲", "z": "z̲",
        "A": "A̲", "B": "B̲", "C": "C̲", "D": "D̲", "E": "E̲", "F": "F̲", "G": "G̲", "H": "H̲", "I": "I̲", "J": "J̲",
        "K": "K̲", "L": "L̲", "M": "M̲", "N": "N̲", "O": "O̲", "P": "P̲", "Q": "Q̲", "R": "R̲", "S": "S̲", "T": "T̲",
        "U": "U̲", "V": "V̲", "W": "W̲", "X": "X̲", "Y": "Y̲", "Z": "Z̲",
        "0": "0̲", "1": "1̲", "2": "2̲", "3": "3̲", "4": "4̲", "5": "5̲", "6": "6̲", "7": "7̲", "8": "8̲", "9": "9̲",
    },
}

def font_text(text, style="bold"):
    """Convert text to the specified font style."""
    styled_text = []
    for char in text:
        # Get the font mapping for the specified style
        font_mapping = FONT_STYLES.get(style, {})
        # Get the styled character or default to the original character
        styled_char = font_mapping.get(char, char)
        # Append the styled character to the result list
        styled_text.append(styled_char)
    # Join the list into a single string and return it
    return "".join(styled_text)


ASCII_STYLES = {
    "standard": {
        'A': [" ███   ", "█   █  ", "█████  ", "█   █  ", "█   █  "],
        'B': ["████   ", "█   █  ", "████   ", "█   █  ", "████   "],
        'C': [" ████  ", "█      ", "█      ", "█      ", " ████  "],
        'D': ["████   ", "█   █  ", "█   █  ", "█   █  ", "████   "],
        'E': ["█████  ", "█      ", "████   ", "█      ", "█████  "],
        'F': ["█████  ", "█      ", "████   ", "█      ", "█      "],
        'G': [" ████  ", "█      ", "█  ██  ", "█   █  ", " ████  "],
        'H': ["█   █  ", "█   █  ", "█████  ", "█   █  ", "█   █  "],
        'I': ["█████  ", "  █    ", "  █    ", "  █    ", "█████  "],
        'J': ["  ███  ", "    █  ", "    █  ", "█   █  ", " ███   "],
        'K': ["█   █  ", "█  █   ", "███    ", "█  █   ", "█   █  "],
        'L': ["█      ", "█      ", "█      ", "█      ", "█████  "],
        'M': ["█   █  ", "██ ██  ", "█ █ █  ", "█   █  ", "█   █  "],
        'N': ["█   █  ", "██  █  ", "█ █ █  ", "█  ██  ", "█   █  "],
        'O': [" ███   ", "█   █  ", "█   █  ", "█   █  ", " ███   "],
        'P': ["████   ", "█   █  ", "████   ", "█      ", "█      "],
        'Q': [" ███   ", "█   █  ", "█ █ █  ", "█  ██  ", " ████  "],
        'R': ["████   ", "█   █  ", "████   ", "█  █   ", "█   █  "],
        'S': [" ████  ", "█      ", " ███   ", "    █  ", "████   "],
        'T': ["█████  ", "  █    ", "  █    ", "  █    ", "  █    "],
        'U': ["█   █  ", "█   █  ", "█   █  ", "█   █  ", " ███   "],
        'V': ["█   █  ", "█   █  ", "█   █  ", " █ █   ", "  █    "],
        'W': ["█   █  ", "█   █  ", "█ █ █  ", "██ ██  ", "█   █  "],
        'X': ["█   █  ", " █ █   ", "  █    ", " █ █   ", "█   █  "],
        'Y': ["█   █  ", " █ █   ", "  █    ", "  █    ", "  █    "],
        'Z': ["█████  ", "   █   ", "  █    ", " █     ", "█████  "],
        'a': ["      ", " ███  ", "   █  ", " ███  ", "█ ██  "],
        'b': ["█     ", "█     ", "████  ", "█   █ ", "████  "],
        'c': ["      ", " ███  ", "█     ", "█     ", " ███  "],
        'd': ["    █ ", "    █ ", " ████ ", "█   █ ", " ████ "],
        'e': ["      ", " ███  ", "████  ", "█     ", " ███  "],
        'f': [" ███  ", "█     ", "███   ", "█     ", "█     "],
        'g': ["      ", " ████ ", "█   █ ", " ████ ", "    █ ", " ███  "],
        'h': ["█     ", "█     ", "████  ", "█   █ ", "█   █ "],
        'i': ["█ ", "  ", "█ ", "█ ", "█ "],
        'j': ["  █ ", "    ", "  █ ", "  █ ", "█ █ ", " ██  "],
        'k': ["█    ", "█  █ ", "███  ", "█  █ ", "█   █"],
        'l': ["█ ", "█ ", "█ ", "█ ", "█ "],
        'm': ["       ", "█ █ █ ", "█ █ █ ", "█ █ █ ", "█ █ █ "],
        'n': ["      ", "████  ", "█   █ ", "█   █ ", "█   █ "],
        'o': ["      ", " ███  ", "█   █ ", "█   █ ", " ███  "],
        'p': ["      ", "████  ", "█   █ ", "████  ", "█     ", "█     "],
        'q': ["      ", " ████ ", "█   █ ", " ████ ", "    █ ", "    █ "],
        'r': ["      ", "█ ██  ", "██    ", "█     ", "█     "],
        's': ["     ", " ███ ", "█    ", " ███ ", "   █ ", "███  "],
        't': [" █   ", "███  ", " █   ", " █   ", " ██  "],
        'u': ["      ", "█   █ ", "█   █ ", "█   █ ", " ████ "],
        'v': ["     ", "█   █", "█   █", " █ █ ", "  █  "],
        'w': ["       ", "█   █ ", "█   █ ", "█ █ █ ", " █ █  "],
        'x': ["      ", "█   █", " █ █ ", "  █  ", "█   █"],
        'y': ["      ", "█   █ ", " █ █  ", "  █   ", " █    ", "█     "],
        'z': ["      ", "████ ", "   █ ", "  █  ", "████ "],
        '0': [" ███   ", "█  ██  ", "█ █ █  ", "██  █  ", " ███   "],
        '1': ["  █    ", " ██    ", "  █    ", "  █    ", "█████  "],
        '2': ["████   ", "    █  ", " ███   ", "█      ", "█████  "],
        '3': ["████   ", "    █  ", " ███   ", "    █  ", "████   "],
        '4': ["█   █  ", "█   █  ", "█████  ", "    █  ", "    █  "],
        '5': ["█████  ", "█      ", "████   ", "    █  ", "████   "],
        '6': [" ███   ", "█      ", "████   ", "█   █  ", " ███   "],
        '7': ["█████  ", "    █  ", "   █   ", "  █    ", " █     "],
        '8': [" ███   ", "█   █  ", " ███   ", "█   █  ", " ███   "],
        '9': [" ███   ", "█   █  ", " ████  ", "    █  ", " ███   "],
        '!': ["█ ", "█ ", "█ ", "  ", "█ "],
        '?': ["███  ", "   █ ", "  █  ", "     ", "  █  "],
        '.': ["  ", "  ", "  ", "  ", "█ "],
        ',': ["  ", "  ", "  ", " █", "█ "],
        ':': ["  ", "█ ", "  ", "█ ", "  "],
        ';': ["  ", "█ ", "  ", " █", "█ "],
        "'": ["█ ", "█ ", "  ", "  ", "  "],
        '"': ["█ █ ", "█ █ ", "    ", "    ", "    "],
        '(': [" █ ", "█  ", "█  ", "█  ", " █ "],
        ')': ["█  ", " █ ", " █ ", " █ ", "█  "],
        '[': ["██ ", "█  ", "█  ", "█  ", "██ "],
        ']': ["██ ", "  █", "  █", "  █", "██ "],
        '{': [" ██", "█  ", "██ ", "█  ", " ██"],
        '}': ["██ ", "  █", " ██", "  █", "██ "],
        '<': ["  █", " █ ", "█  ", " █ ", "  █"],
        '>': ["█  ", " █ ", "  █", " █ ", "█  "],
        '/': ["   █", "  █ ", " █  ", "█   ", "    "],
        '\\': ["█    ", " █   ", "  █  ", "   █ ", "     "],
        '|': ["█ ", "█ ", "█ ", "█ ", "█ "],
        '-': ["    ", "    ", "███ ", "    ", "    "],
        '_': ["    ", "    ", "    ", "    ", "███ "],
        '=': ["    ", "███ ", "    ", "███ ", "    "],
        '+': ["    ", " █  ", "████", " █  ", "    "],
        '*': ["    ", "█ ██", " ██ ", "█ ██", "    "],
        '#': [" █ █ ", "█████", " █ █ ", "█████", " █ █ "],
        '$': [" ██ ", "█ ██", " ██ ", "██ █", " ██ "],
        '%': ["█  █", "   █", "  █ ", " █  ", "█  █"],
        '^': [" █  ", "█ █ ", "    ", "    ", "    "],
        '&': [" █   ", "█ █  ", " █   ", "█ █ █", " █ █ "],
        '@': [" ███ ", "█   █", "█ ███", "█ █ █", " ███ "],
        ' ': ["  ", "  ", "  ", "  ", "  "]
    },
    "outline": {
        'A': [" ███   ", "█   █  ", "█ █ █  ", "█   █  ", "█   █  "],
        'B': ["████   ", "█   █  ", "█ ██   ", "█   █  ", "████   "],
        'C': [" ████  ", "█      ", "█      ", "█      ", " ████  "],
        'D': ["████   ", "█   █  ", "█   █  ", "█   █  ", "████   "],
        'E': ["█████  ", "█      ", "████   ", "█      ", "█████  "],
        'F': ["█████  ", "█      ", "████   ", "█      ", "█      "],
        'G': [" ████  ", "█      ", "█  ██  ", "█   █  ", " ████  "],
        'H': ["█   █  ", "█   █  ", "█ █ █  ", "█   █  ", "█   █  "],
        'I': ["█████  ", "  █    ", "  █    ", "  █    ", "█████  "],
        'J': ["  ███  ", "    █  ", "    █  ", "█   █  ", " ███   "],
        'K': ["█   █  ", "█  █   ", "███    ", "█  █   ", "█   █  "],
        'L': ["█      ", "█      ", "█      ", "█      ", "█████  "],
        'M': ["█   █  ", "██ ██  ", "█ █ █  ", "█   █  ", "█   █  "],
        'N': ["█   █  ", "██  █  ", "█ █ █  ", "█  ██  ", "█   █  "],
        'O': [" ███   ", "█   █  ", "█   █  ", "█   █  ", " ███   "],
        'P': ["████   ", "█   █  ", "████   ", "█      ", "█      "],
        'Q': [" ███   ", "█   █  ", "█ █ █  ", "█  ██  ", " ████  "],
        'R': ["████   ", "█   █  ", "████   ", "█  █   ", "█   █  "],
        'S': [" ████  ", "█      ", " ███   ", "    █  ", "████   "],
        'T': ["█████  ", "  █    ", "  █    ", "  █    ", "  █    "],
        'U': ["█   █  ", "█   █  ", "█   █  ", "█   █  ", " ███   "],
        'V': ["█   █  ", "█   █  ", "█   █  ", " █ █   ", "  █    "],
        'W': ["█   █  ", "█   █  ", "█ █ █  ", "██ ██  ", "█   █  "],
        'X': ["█   █  ", " █ █   ", "  █    ", " █ █   ", "█   █  "],
        'Y': ["█   █  ", " █ █   ", "  █    ", "  █    ", "  █    "],
        'Z': ["█████  ", "   █   ", "  █    ", " █     ", "█████  "],
        'a': ["      ", " ███  ", "   █  ", " ███  ", "█ ██  "],
        'b': ["█     ", "█     ", "████  ", "█   █ ", "████  "],
        'c': ["      ", " ███  ", "█     ", "█     ", " ███  "],
        'd': ["    █ ", "    █ ", " ████ ", "█   █ ", " ████ "],
        'e': ["      ", " ███  ", "████  ", "█     ", " ███  "],
        'f': [" ███  ", "█     ", "███   ", "█     ", "█     "],
        'g': ["      ", " ████ ", "█   █ ", " ████ ", "    █ ", " ███  "],
        'h': ["█     ", "█     ", "████  ", "█   █ ", "█   █ "],
        'i': ["█ ", "  ", "█ ", "█ ", "█ "],
        'j': ["  █ ", "    ", "  █ ", "  █ ", "█ █ ", " ██  "],
        'k': ["█    ", "█  █ ", "███  ", "█  █ ", "█   █"],
        'l': ["█ ", "█ ", "█ ", "█ ", "█ "],
        'm': ["       ", "█ █ █ ", "█ █ █ ", "█ █ █ ", "█ █ █ "],
        'n': ["      ", "████  ", "█   █ ", "█   █ ", "█   █ "],
        'o': ["      ", " ███  ", "█   █ ", "█   █ ", " ███  "],
        'p': ["      ", "████  ", "█   █ ", "████  ", "█     ", "█     "],
        'q': ["      ", " ████ ", "█   █ ", " ████ ", "    █ ", "    █ "],
        'r': ["      ", "█ ██  ", "██    ", "█     ", "█     "],
        's': ["     ", " ███ ", "█    ", " ███ ", "   █ ", "███  "],
        't': [" █   ", "███  ", " █   ", " █   ", " ██  "],
        'u': ["      ", "█   █ ", "█   █ ", "█   █ ", " ████ "],
        'v': ["     ", "█   █", "█   █", " █ █ ", "  █  "],
        'w': ["       ", "█   █ ", "█   █ ", "█ █ █ ", " █ █  "],
        'x': ["      ", "█   █", " █ █ ", "  █  ", "█   █"],
        'y': ["      ", "█   █ ", " █ █  ", "  █   ", " █    ", "█     "],
        'z': ["      ", "████ ", "   █ ", "  █  ", "████ "],
        '0': [" ███   ", "█  ██  ", "█ █ █  ", "██  █  ", " ███   "],
        '1': ["  █    ", " ██    ", "  █    ", "  █    ", "█████  "],
        '2': ["████   ", "    █  ", " ███   ", "█      ", "█████  "],
        '3': ["████   ", "    █  ", " ███   ", "    █  ", "████   "],
        '4': ["█   █  ", "█   █  ", "█████  ", "    █  ", "    █  "],
        '5': ["█████  ", "█      ", "████   ", "    █  ", "████   "],
        '6': [" ███   ", "█      ", "████   ", "█   █  ", " ███   "],
        '7': ["█████  ", "    █  ", "   █   ", "  █    ", " █     "],
        '8': [" ███   ", "█   █  ", " ███   ", "█   █  ", " ███   "],
        '9': [" ███   ", "█   █  ", " ████  ", "    █  ", " ███   "],
        '!': ["█ ", "█ ", "█ ", "  ", "█ "],
        '?': ["███  ", "   █ ", "  █  ", "     ", "  █  "],
        '.': ["  ", "  ", "  ", "  ", "█ "],
        ',': ["  ", "  ", "  ", " █", "█ "],
        ':': ["  ", "█ ", "  ", "█ ", "  "],
        ';': ["  ", "█ ", "  ", " █", "█ "],
        "'": ["█ ", "█ ", "  ", "  ", "  "],
        '"': ["█ █ ", "█ █ ", "    ", "    ", "    "],
        '(': [" █ ", "█  ", "█  ", "█  ", " █ "],
        ')': ["█  ", " █ ", " █ ", " █ ", "█  "],
        '[': ["██ ", "█  ", "█  ", "█  ", "██ "],
        ']': ["██ ", "  █", "  █", "  █", "██ "],
        '{': [" ██", "█  ", "██ ", "█  ", " ██"],
        '}': ["██ ", "  █", " ██", "  █", "██ "],
        '<': ["  █", " █ ", "█  ", " █ ", "  █"],
        '>': ["█  ", " █ ", "  █", " █ ", "█  "],
        '/': ["   █", "  █ ", " █  ", "█   ", "    "],
        '\\': ["█    ", " █   ", "  █  ", "   █ ", "     "],
        '|': ["█ ", "█ ", "█ ", "█ ", "█ "],
        '-': ["    ", "    ", "███ ", "    ", "    "],
        '_': ["    ", "    ", "    ", "    ", "███ "],
        '=': ["    ", "███ ", "    ", "███ ", "    "],
        '+': ["    ", " █  ", "████", " █  ", "    "],
        '*': ["    ", "█ ██", " ██ ", "█ ██", "    "],
        '#': [" █ █ ", "█████", " █ █ ", "█████", " █ █ "],
        '$': [" ██ ", "█ ██", " ██ ", "██ █", " ██ "],
        '%': ["█  █", "   █", "  █ ", " █  ", "█  █"],
        '^': [" █  ", "█ █ ", "    ", "    ", "    "],
        '&': [" █   ", "█ █  ", " █   ", "█ █ █", " █ █ "],
        '@': [" ███ ", "█   █", "█ ███", "█ █ █", " ███ "],
        ' ': ["  ", "  ", "  ", "  ", "  "]
    },
    "bubble": {
        'A': [" ░██░  ", "█░░░█  ", "█████  ", "█░░░█  ", "█░░░█  "],
        'B': ["████░  ", "█░░░█  ", "████░  ", "█░░░█  ", "████░  "],
        'C': [" ░███  ", "█░░░░  ", "█░░░░  ", "█░░░░  ", " ░███  "],
        'D': ["████░  ", "█░░░█  ", "█░░░█  ", "█░░░█  ", "████░  "],
        'E': ["█████  ", "█░░░░  ", "████░  ", "█░░░░  ", "█████  "],
        'F': ["█████  ", "█░░░░  ", "████░  ", "█░░░░  ", "█░░░░  "],
        'G': [" ░███  ", "█░░░░  ", "█░░██  ", "█░░░█  ", " ░███  "],
        'H': ["█░░░█  ", "█░░░█  ", "█████  ", "█░░░█  ", "█░░░█  "],
        'I': ["█████  ", "░░█░░  ", "░░█░░  ", "░░█░░  ", "█████  "],
        'J': ["░░███  ", "░░░█░  ", "░░░█░  ", "█░░█░  ", "░███░  "],
        'K': ["█░░░█  ", "█░░█░  ", "████░  ", "█░░█░  ", "█░░░█  "],
        'L': ["█░░░░  ", "█░░░░  ", "█░░░░  ", "█░░░░  ", "█████  "],
        'M': ["█░░░█  ", "██░██  ", "█░█░█  ", "█░░░█  ", "█░░░█  "],
        'N': ["█░░░█  ", "██░░█  ", "█░█░█  ", "█░░██  ", "█░░░█  "],
        'O': [" ░██░  ", "█░░░█  ", "█░░░█  ", "█░░░█  ", " ░██░  "],
        'P': ["████░  ", "█░░░█  ", "████░  ", "█░░░░  ", "█░░░░  "],
        'Q': [" ░██░  ", "█░░░█  ", "█░█░█  ", "█░░██  ", " ░███  "],
        'R': ["████░  ", "█░░░█  ", "████░  ", "█░░█░  ", "█░░░█  "],
        'S': [" ░███  ", "█░░░░  ", " ░██░  ", "░░░█░  ", "████░  "],
        'T': ["█████  ", "░░█░░  ", "░░█░░  ", "░░█░░  ", "░░█░░  "],
        'U': ["█░░░█  ", "█░░░█  ", "█░░░█  ", "█░░░█  ", " ░██░  "],
        'V': ["█░░░█  ", "█░░░█  ", "█░░░█  ", "░█░█░  ", "░░█░░  "],
        'W': ["█░░░█  ", "█░░░█  ", "█░█░█  ", "██░██  ", "█░░░█  "],
        'X': ["█░░░█  ", "░█░█░  ", "░░█░░  ", "░█░█░  ", "█░░░█  "],
        'Y': ["█░░░█  ", "░█░█░  ", "░░█░░  ", "░░█░░  ", "░░█░░  "],
        'Z': ["█████  ", "░░░█░  ", "░░█░░  ", "░█░░░  ", "█████  "],
        'a': ["      ", " ░██  ", "░░░█  ", " ███  ", "█░██  "],
        'b': ["█░░   ", "█░░   ", "████  ", "█░░░█ ", "████  "],
        'c': ["      ", " ░██  ", "█░░░  ", "█░░░  ", " ░██  "],
        'd': ["░░░█ ", "░░░█ ", " ████ ", "█░░░█ ", " ████ "],
        'e': ["      ", " ░██  ", "████  ", "█░░░  ", " ░██  "],
        'f': [" ███  ", "█░░   ", "███   ", "█░░   ", "█░░   "],
        'g': ["      ", " ████ ", "█░░░█ ", " ████ ", "░░░█ ", " ░██  "],
        'h': ["█░░   ", "█░░   ", "████  ", "█░░░█ ", "█░░░█ "],
        'i': ["█ ", "░ ", "█ ", "█ ", "█ "],
        'j': [" █ ", "   ", " █ ", " █ ", "█░█ ", " ██  "],
        'k': ["█    ", "█░ █ ", "███  ", "█░ █ ", "█░░ █"],
        'l': ["█ ", "█ ", "█ ", "█ ", "█ "],
        'm': ["       ", "█░█░█ ", "█░█░█ ", "█░█░█ ", "█░█░█ "],
        'n': ["      ", "████  ", "█░░░█ ", "█░░░█ ", "█░░░█ "],
        'o': ["      ", " ░██  ", "█░░░█ ", "█░░░█ ", " ░██  "],
        'p': ["      ", "████  ", "█░░░█ ", "████  ", "█░░   ", "█░░   "],
        'q': ["      ", " ████ ", "█░░░█ ", " ████ ", "░░░█ ", "░░░█ "],
        'r': ["      ", "█░██  ", "███   ", "█░░   ", "█░░   "],
        's': ["     ", " ███ ", "█░░  ", " ███ ", "░░░█ ", "███  "],
        't': [" █   ", "███  ", " █   ", " █   ", " ██  "],
        'u': ["      ", "█░░░█ ", "█░░░█ ", "█░░░█ ", " ████ "],
        'v': ["     ", "█░░░█", "█░░░█", " █░█ ", " ░█  "],
        'w': ["       ", "█░░░█ ", "█░░░█ ", "█░█░█ ", " █░█  "],
        'x': ["      ", "█░░░█", " █░█ ", " ░█  ", "█░░░█"],
        'y': ["      ", "█░░░█ ", " █░█  ", " ░█   ", " █    ", "█     "],
        'z': ["      ", "████ ", "░░░█ ", " ██  ", "████ "],
        '0': [" ░██   ", "█░ ██  ", "█░█░█  ", "██ ░█  ", " ░██   "],
        '1': [" ░█    ", "░██    ", " ░█    ", " ░█    ", "█████  "],
        '2': ["████   ", "░░░█   ", " ███   ", "█░░░   ", "█████  "],
        '3': ["████   ", "░░░█   ", " ███   ", "░░░█   ", "████   "],
        '4': ["█░░░█  ", "█░░░█  ", "█████  ", "░░░░█  ", "░░░░█  "],
        '5': ["█████  ", "█░░░░  ", "████   ", "░░░█   ", "████   "],
        '6': [" ███   ", "█░░░   ", "████   ", "█░░░█  ", " ███   "],
        '7': ["█████  ", "░░░█   ", "░░█    ", "░█     ", "█      "],
        '8': [" ███   ", "█░░░█  ", " ███   ", "█░░░█  ", " ███   "],
        '9': [" ███   ", "█░░░█  ", " ████  ", "░░░█   ", " ███   "],
        '!': ["█ ", "█ ", "█ ", "░ ", "█ "],
        '?': ["███  ", "░░░█ ", " ██  ", "     ", " █   "],
        '.': ["  ", "  ", "  ", "  ", "█ "],
        ',': ["  ", "  ", "  ", " █", "█ "],
        ':': ["  ", "█ ", "  ", "█ ", "  "],
        ';': ["  ", "█ ", "  ", " █", "█ "],
        "'": ["█ ", "█ ", "  ", "  ", "  "],
        '"': ["█░█ ", "█░█ ", "    ", "    ", "    "],
        '(': [" █ ", "█░ ", "█░ ", "█░ ", " █ "],
        ')': ["█  ", "░█ ", "░█ ", "░█ ", "█  "],
        '[': ["██ ", "█░ ", "█░ ", "█░ ", "██ "],
        ']': ["██ ", "░█ ", "░█ ", "░█ ", "██ "],
        '{': [" ██", "█░ ", "██ ", "█░ ", " ██"],
        '}': ["██ ", " ░█", " ██", " ░█", "██ "],
        '<': [" ░█", " █ ", "█  ", " █ ", " ░█"],
        '>': ["█░ ", " █ ", " ░█", " █ ", "█░ "],
        '/': ["░░░█", " ░█ ", " █  ", "█   ", "    "],
        '\\': ["█    ", "░█   ", " █   ", "  █  ", "     "],
        '|': ["█ ", "█ ", "█ ", "█ ", "█ "],
        '-': ["    ", "    ", "███ ", "    ", "    "],
        '_': ["    ", "    ", "    ", "    ", "███ "],
        '=': ["    ", "███ ", "    ", "███ ", "    "],
        '+': ["    ", " █  ", "████", " █  ", "    "],
        '*': ["    ", "█░██", " ██ ", "█░██", "    "],
        '#': [" █░█ ", "█████", " █░█ ", "█████", " █░█ "],
        '$': [" ██ ", "█░██", " ██ ", "██░█", " ██ "],
        '%': ["█░░█", "░░░█", " ░█ ", " █░░", "█░░█"],
        '^': [" █  ", "█░█ ", "    ", "    ", "    "],
        '&': [" █   ", "█░█  ", " █   ", "█░█░█", " █░█ "],
        '@': [" ███ ", "█░░░█", "█░███", "█░█░█", " ███ "],
        ' ': ["  ", "  ", "  ", "  ", "  "]
    },
    "shadow": {
        'A': [" ███   ", "█   █  ", "█████  ", "█   █▓ ", "█████▓ "],
        'B': ["████   ", "█   █  ", "████   ", "█   █▓ ", "████▓  "],
        'C': [" ████  ", "█      ", "█      ", "█      ", " ████▓ "],
        'D': ["████   ", "█   █  ", "█   █  ", "█   █  ", "████▓  "],
        'E': ["█████  ", "█      ", "████   ", "█      ", "█████▓ "],
        'F': ["█████  ", "█      ", "████   ", "█      ", "█▓     "],
        'G': [" ████  ", "█      ", "█  ██  ", "█   █  ", " ████▓ "],
        'H': ["█   █  ", "█   █  ", "█████  ", "█   █▓ ", "█   █▓ "],
        'I': ["█████  ", "  █    ", "  █    ", "  █    ", "█████▓ "],
        'J': ["  ███  ", "    █  ", "    █  ", "█   █▓ ", " ███▓  "],
        'K': ["█   █  ", "█  █   ", "███    ", "█  █▓  ", "█   █▓ "],
        'L': ["█      ", "█      ", "█      ", "█      ", "█████▓ "],
        'M': ["█   █  ", "██ ██  ", "█ █ █  ", "█   █▓ ", "█   █▓ "],
        'N': ["█   █  ", "██  █  ", "█ █ █  ", "█  ██▓ ", "█   █▓ "],
        'O': [" ███   ", "█   █  ", "█   █  ", "█   █▓ ", " ███▓  "],
        'P': ["████   ", "█   █  ", "████   ", "█▓     ", "█▓     "],
        'Q': [" ███   ", "█   █  ", "█ █ █  ", "█  ██▓ ", " ████▓ "],
        'R': ["████   ", "█   █  ", "████   ", "█  █▓  ", "█   █▓ "],
        'S': [" ████  ", "█      ", " ███   ", "    █▓ ", "████▓  "],
        'T': ["█████  ", "  █    ", "  █    ", "  █▓   ", "  █▓   "],
        'U': ["█   █  ", "█   █  ", "█   █  ", "█   █▓ ", " ███▓  "],
        'V': ["█   █  ", "█   █  ", "█   █  ", " █ █▓  ", "  █▓   "],
        'W': ["█   █  ", "█   █  ", "█ █ █  ", "██ ██▓ ", "█   █▓ "],
        'X': ["█   █  ", " █ █   ", "  █    ", " █ █▓  ", "█   █▓ "],
        'Y': ["█   █  ", " █ █   ", "  █    ", "  █▓   ", "  █▓   "],
        'Z': ["█████  ", "   █   ", "  █    ", " █▓    ", "█████▓ "],
        'a': ["      ", " ███  ", "   █  ", " ███  ", "█ ██▓ "],
        'b': ["█     ", "█     ", "████  ", "█   █▓", "████▓ "],
        'c': ["      ", " ███  ", "█     ", "█     ", " ███▓ "],
        'd': ["    █ ", "    █ ", " ████ ", "█   █▓", " ████▓"],
        'e': ["      ", " ███  ", "████  ", "█     ", " ███▓ "],
        'f': [" ███  ", "█     ", "███   ", "█▓    ", "█▓    "],
        'g': ["      ", " ████ ", "█   █▓", " ████ ", "    █▓", " ███▓ "],
        'h': ["█     ", "█     ", "████  ", "█   █▓", "█   █▓"],
        'i': ["█ ", "  ", "█ ", "█ ", "█▓"],
        'j': ["  █ ", "    ", "  █ ", "  █ ", "█ █▓", " ██▓ "],
        'k': ["█    ", "█  █ ", "███  ", "█  █▓", "█   █▓"],
        'l': ["█ ", "█ ", "█ ", "█ ", "█▓"],
        'm': ["       ", "█ █ █ ", "█ █ █ ", "█ █ █▓", "█ █ █▓"],
        'n': ["      ", "████  ", "█   █▓", "█   █▓", "█   █▓"],
        'o': ["      ", " ███  ", "█   █▓", "█   █▓", " ███▓ "],
        'p': ["      ", "████  ", "█   █▓", "████  ", "█▓    ", "█▓    "],
        'q': ["      ", " ████ ", "█   █▓", " ████ ", "    █▓", "    █▓"],
        'r': ["      ", "█ ██  ", "███   ", "█▓    ", "█▓    "],
        's': ["     ", " ███ ", "█    ", " ███ ", "   █▓", "███▓ "],
        't': [" █   ", "███  ", " █   ", " █▓  ", " ██▓ "],
        'u': ["      ", "█   █▓", "█   █▓", "█   █▓", " ████▓"],
        'v': ["     ", "█   █▓", "█   █▓", " █ █▓ ", "  █▓  "],
        'w': ["       ", "█   █▓", "█   █▓", "█ █ █▓", " █ █▓ "],
        'x': ["      ", "█   █▓", " █ █▓ ", "  █▓  ", "█   █▓"],
        'y': ["      ", "█   █▓", " █ █▓ ", "  █▓  ", " █▓   ", "█▓    "],
        'z': ["      ", "████▓", "   █ ", "  █▓ ", "████▓"],
        '0': [" ███   ", "█  ██  ", "█ █ █  ", "██  █▓ ", " ███▓  "],
        '1': ["  █    ", " ██    ", "  █    ", "  █▓   ", "█████▓ "],
        '2': ["████   ", "    █  ", " ███   ", "█▓     ", "█████▓ "],
        '3': ["████   ", "    █  ", " ███   ", "    █▓ ", "████▓  "],
        '4': ["█   █  ", "█   █  ", "█████  ", "    █▓ ", "    █▓ "],
        '5': ["█████  ", "█      ", "████   ", "    █▓ ", "████▓  "],
        '6': [" ███   ", "█      ", "████   ", "█   █▓ ", " ███▓  "],
        '7': ["█████  ", "    █  ", "   █   ", "  █▓   ", " █▓    "],
        '8': [" ███   ", "█   █  ", " ███   ", "█   █▓ ", " ███▓  "],
        '9': [" ███   ", "█   █  ", " ████  ", "    █▓ ", " ███▓  "],
        '!': ["█ ", "█ ", "█ ", "▓ ", "█▓"],
        '?': ["███  ", "   █ ", "  █  ", "▓    ", " █▓  "],
        '.': ["  ", "  ", "  ", "  ", "█▓"],
        ',': ["  ", "  ", "  ", " █", "█▓"],
        ':': ["  ", "█ ", "  ", "█▓", "  "],
        ';': ["  ", "█ ", "  ", " █", "█▓"],
        "'": ["█ ", "█ ", "  ", "  ", "  "],
        '"': ["█ █ ", "█ █ ", "    ", "    ", "    "],
        '(': [" █ ", "█  ", "█  ", "█▓ ", " █▓"],
        ')': ["█  ", " █ ", " █ ", " █▓", "█▓ "],
        '[': ["██ ", "█  ", "█  ", "█▓ ", "██▓"],
        ']': ["██ ", " █ ", " █ ", " █▓", "██▓"],
        '{': [" ██", "█  ", "██ ", "█▓ ", " ██▓"],
        '}': ["██ ", " █ ", " ██", " █▓", "██▓"],
        '<': ["  █", " █ ", "█  ", " █▓", "  █▓"],
        '>': ["█  ", " █ ", "  █", " █▓", "█▓ "],
        '/': ["   █", "  █ ", " █  ", "█▓  ", "    "],
        '\\': ["█    ", " █   ", "  █  ", "   █▓", "     "],
        '|': ["█ ", "█ ", "█ ", "█▓", "█▓"],
        '-': ["    ", "    ", "███ ", "▓   ", "    "],
        '_': ["    ", "    ", "    ", "    ", "███▓"],
        '=': ["    ", "███ ", "▓   ", "███ ", "    "],
        '+': ["    ", " █  ", "████", " █▓ ", "    "],
        '*': ["    ", "█ ██", " ██ ", "█ █▓", "    "],
        '#': [" █ █ ", "█████", " █ █ ", "████▓", " █ █▓"],
        '$': [" ██ ", "█ ██", " ██ ", "██ █▓", " ██▓ "],
        '%': ["█  █", "   █", "  █ ", " █  ", "█  █▓"],
        '^': [" █  ", "█ █ ", "    ", "    ", "    "],
        '&': [" █   ", "█ █  ", " █   ", "█ █ █▓", " █ █▓ "],
        '@': [" ███ ", "█   █", "█ ███", "█ █ █▓", " ███▓ "],
        ' ': ["  ", "  ", "  ", "  ", "  "]
    },
    "minimal": {
        'A': ["  A  ", " A A ", "AAAAA", "A   A", "A   A"],
        'B': ["BBBB ", "B   B", "BBBB ", "B   B", "BBBB "],
        'C': [" CCC ", "C    ", "C    ", "C    ", " CCC "],
        'D': ["DDD  ", "D  D ", "D   D", "D  D ", "DDD  "],
        'E': ["EEEEE", "E    ", "EEE  ", "E    ", "EEEEE"],
        'F': ["FFFFF", "F    ", "FFF  ", "F    ", "F    "],
        'G': [" GGG ", "G    ", "G GG ", "G  G ", " GGG "],
        'H': ["H   H", "H   H", "HHHHH", "H   H", "H   H"],
        'I': ["IIIII", "  I  ", "  I  ", "  I  ", "IIIII"],
        'J': ["JJJJJ", "    J", "    J", "J   J", " JJJ "],
        'K': ["K  K ", "K K  ", "KK   ", "K K  ", "K  K "],
        'L': ["L    ", "L    ", "L    ", "L    ", "LLLLL"],
        'M': ["M   M", "MM MM", "M M M", "M   M", "M   M"],
        'N': ["N   N", "NN  N", "N N N", "N  NN", "N   N"],
        'O': [" OOO ", "O   O", "O   O", "O   O", " OOO "],
        'P': ["PPPP ", "P   P", "PPPP ", "P    ", "P    "],
        'Q': [" QQQ ", "Q   Q", "Q Q Q", "Q  Q ", " QQ Q"],
        'R': ["RRRR ", "R   R", "RRRR ", "R R  ", "R  R "],
        'S': [" SSS ", "S    ", " SSS ", "    S", "SSSS "],
        'T': ["TTTTT", "  T  ", "  T  ", "  T  ", "  T  "],
        'U': ["U   U", "U   U", "U   U", "U   U", " UUU "],
        'V': ["V   V", "V   V", "V   V", " V V ", "  V  "],
        'W': ["W   W", "W   W", "W W W", "WW WW", "W   W"],
        'X': ["X   X", " X X ", "  X  ", " X X ", "X   X"],
        'Y': ["Y   Y", " Y Y ", "  Y  ", "  Y  ", "  Y  "],
        'Z': ["ZZZZZ", "   Z ", "  Z  ", " Z   ", "ZZZZZ"],
        'a': ["     ", " aa  ", "a  a ", "aaaa ", "a  a "],
        'b': ["b    ", "b    ", "bbbb ", "b   b", "bbbb "],
        'c': ["     ", " ccc ", "c    ", "c    ", " ccc "],
        'd': ["    d", "    d", " dddd", "d   d", " dddd"],
        'e': ["     ", " eee ", "eeee ", "e    ", " eee "],
        'f': [" fff ", "f    ", "fff  ", "f    ", "f    "],
        'g': ["     ", " gggg", "g   g", " gggg", "    g", " ggg "],
        'h': ["h    ", "h    ", "hhhh ", "h   h", "h   h"],
        'i': ["i ", "  ", "i ", "i ", "i "],
        'j': ["  j ", "    ", "  j ", "  j ", "j j ", " jj "],
        'k': ["k   ", "k  k", "kkk ", "k  k", "k   k"],
        'l': ["l ", "l ", "l ", "l ", "l "],
        'm': ["      ", "m m m", "m m m", "m m m", "m m m"],
        'n': ["     ", "nnnn ", "n   n", "n   n", "n   n"],
        'o': ["     ", " ooo ", "o   o", "o   o", " ooo "],
        'p': ["     ", "pppp ", "p   p", "pppp ", "p    ", "p    "],
        'q': ["     ", " qqqq", "q   q", " qqqq", "    q", "    q"],
        'r': ["     ", "r rr ", "rr   ", "r    ", "r    "],
        's': ["    ", " sss", "s   ", " sss", "   s", "sss "],
        't': [" t  ", "ttt ", " t  ", " t  ", " tt "],
        'u': ["     ", "u   u", "u   u", "u   u", " uuu "],
        'v': ["     ", "v   v", "v   v", " v v ", "  v  "],
        'w': ["      ", "w   w", "w w w", "ww ww", "w   w"],
        'x': ["     ", "x   x", " x x ", "  x  ", "x   x"],
        'y': ["     ", "y   y", " y y ", "  y  ", " y   ", "y    "],
        'z': ["    ", "zzzz", "  z ", " z  ", "zzzz"],
        '0': [" 000 ", "0   0", "0   0", "0   0", " 000 "],
        '1': ["  1  ", " 11  ", "  1  ", "  1  ", "11111"],
        '2': [" 222 ", "2   2", "  2  ", " 2   ", "22222"],
        '3': ["3333 ", "    3", " 333 ", "    3", "3333 "],
        '4': ["4  4 ", "4  4 ", "44444", "   4 ", "   4 "],
        '5': ["55555", "5    ", "5555 ", "    5", "5555 "],
        '6': [" 666 ", "6    ", "6666 ", "6   6", " 666 "],
        '7': ["77777", "   7 ", "  7  ", " 7   ", "7    "],
        '8': [" 888 ", "8   8", " 888 ", "8   8", " 888 "],
        '9': [" 999 ", "9   9", " 9999", "    9", " 999 "],
        '!': [" ! ", " ! ", " ! ", "   ", " ! "],
        '?': [" ??? ", "?   ?", "   ? ", "     ", "  ?  "],
        '.': ["   ", "   ", "   ", "   ", " . "],
        ',': ["   ", "   ", "   ", " , ", ",  "],
        ':': ["   ", " : ", "   ", " : ", "   "],
        ';': ["   ", " ; ", "   ", " ; ", ";  "],
        "'": [" ' ", " ' ", "   ", "   ", "   "],
        '"': [" \" \" ", " \" \" ", "     ", "     ", "     "],
        '(': ["  ( ", " (  ", "(   ", " (  ", "  ( "],
        ')': [" )  ", "  ) ", "   )", "  ) ", " )  "],
        '[': [" [[ ", "[   ", "[   ", "[   ", " [[ "],
        ']': [" ]] ", "   ]", "   ]", "   ]", " ]] "],
        '{': ["  {{", " {  ", "{{  ", " {  ", "  }}"],
        '}': ["}}  ", "  } ", "  }}", "  } ", "}}  "],
        '<': ["   <", " <  ", "<   ", " <  ", "   <"],
        '>': [">   ", "  > ", "   >", "  > ", ">   "],
        '/': ["    /", "   / ", "  /  ", " /   ", "/    "],
        '\\': ["\\    ", " \\   ", "  \\  ", "   \\ ", "    \\"],
        '|': [" | ", " | ", " | ", " | ", " | "],
        '-': ["     ", "     ", " --- ", "     ", "     "],
        '_': ["     ", "     ", "     ", "     ", "_____"],
        '=': ["     ", " === ", "     ", " === ", "     "],
        '+': ["     ", "  +  ", " +++ ", "  +  ", "     "],
        '*': ["     ", " * * ", "  *  ", " * * ", "     "],
        '#': [" # # ", "#####", " # # ", "#####", " # # "],
        '$': ["  $$ ", "$ $ $", " $$  ", "$ $ $", " $$  "],
        '%': ["%   %", "   % ", "  %  ", " %   ", "%   %"],
        '^': [" ^  ", "^ ^ ", "    ", "    ", "    "],
        '&': ["  &  ", " &   ", "  &  ", "& & &", " &&& "],
        '@': [" @@@ ", "@   @", "@ @@ ", "@    ", " @@@ "],
        ' ': [" ", " ", " ", " ", " "]
    },
   
    "dotmatrix": {
    'A': [" █ █ ", "█   █", "█████", "█   █", "█   █"],
    'B': ["████ ", "█   █", "████ ", "█   █", "████ "],
    'C': [" ████", "█    ", "█    ", "█    ", " ████"],
    'D': ["████ ", "█   █", "█   █", "█   █", "████ "],
    'E': ["█████", "█    ", "████ ", "█    ", "█████"],
    'F': ["█████", "█    ", "████ ", "█    ", "█    "],
    'G': [" ████", "█    ", "█  ██", "█   █", " ████"],
    'H': ["█   █", "█   █", "█████", "█   █", "█   █"],
    'I': ["█████", "  █  ", "  █  ", "  █  ", "█████"],
    'J': ["  ███", "    █", "    █", "█   █", " ███ "],
    'K': ["█   █", "█  █ ", "████ ", "█  █ ", "█   █"],
    'L': ["█    ", "█    ", "█    ", "█    ", "█████"],
    'M': ["█   █", "██ ██", "█ █ █", "█   █", "█   █"],
    'N': ["█   █", "██  █", "█ █ █", "█  ██", "█   █"],
    'O': [" ███ ", "█   █", "█   █", "█   █", " ███ "],
    'P': ["████ ", "█   █", "████ ", "█    ", "█    "],
    'Q': [" ███ ", "█   █", "█ █ █", "█  █ ", " ████"],
    'R': ["████ ", "█   █", "████ ", "█  █ ", "█   █"],
    'S': [" ████", "█    ", " ███ ", "    █", "████ "],
    'T': ["█████", "  █  ", "  █  ", "  █  ", "  █  "],
    'U': ["█   █", "█   █", "█   █", "█   █", " ███ "],
    'V': ["█   █", "█   █", "█   █", " █ █ ", "  █  "],
    'W': ["█   █", "█   █", "█ █ █", "██ ██", "█   █"],
    'X': ["█   █", " █ █ ", "  █  ", " █ █ ", "█   █"],
    'Y': ["█   █", " █ █ ", "  █  ", "  █  ", "  █  "],
    'Z': ["█████", "   █ ", "  █  ", " █   ", "█████"],
    ' ': ["     ", "     ", "     ", "     ", "     "],
     'a': ["     ", " ██  ", "█  █ ", "████ ", "█  █ "],
    'b': ["█    ", "█    ", "████ ", "█   █", "████ "],
    'c': ["     ", " ███ ", "█    ", "█    ", " ███ "],
    'd': ["    █", "    █", " ████", "█   █", " ████"],
    'e': ["     ", " ███ ", "████ ", "█    ", " ███ "],
    'f': [" ███ ", "█    ", "███  ", "█    ", "█    "],
    'g': ["     ", " ████", "█   █", " ████", "    █", " ███ "],
    'h': ["█    ", "█    ", "████ ", "█   █", "█   █"],
    'i': ["█", " ", "█", "█", "█"],
    'j': ["  █ ", "    ", "  █ ", "  █ ", "█ █ ", " ██ "],
    'k': ["█   ", "█  █", "███ ", "█  █", "█   █"],
    'l': ["█ ", "█ ", "█ ", "█ ", "█ "],
    'm': ["      ", "█ █ █", "█ █ █", "█ █ █", "█ █ █"],
    'n': ["     ", "████ ", "█   █", "█   █", "█   █"],
    'o': ["     ", " ███ ", "█   █", "█   █", " ███ "],
    'p': ["     ", "████ ", "█   █", "████ ", "█    ", "█    "],
    'q': ["     ", " ████", "█   █", " ████", "    █", "    █"],
    'r': ["     ", "█ ██ ", "██   ", "█    ", "█    "],
    's': ["    ", " ███", "█   ", " ███", "   █", "███ "],
    't': [" █  ", "███ ", " █  ", " █  ", " ██ "],
    'u': ["     ", "█   █", "█   █", "█   █", " ███ "],
    'v': ["     ", "█   █", "█   █", " █ █ ", "  █  "],
    'w': ["      ", "█   █", "█ █ █", "██ ██", "█   █"],
    'x': ["     ", "█   █", " █ █ ", "  █  ", "█   █"],
    'y': ["     ", "█   █", " █ █ ", "  █  ", " █   ", "█    "],
    'z': ["    ", "████", "  █ ", " █  ", "████"],
    '0': [" ███ ", "█   █", "█   █", "█   █", " ███ "],
    '1': ["  █  ", " ██  ", "  █  ", "  █  ", "█████"],
    '2': [" ███ ", "█   █", "   █ ", " █   ", "█████"],
    '3': ["████ ", "    █", " ███ ", "    █", "████ "],
    '4': ["█   █", "█   █", "█████", "    █", "    █"],
    '5': ["█████", "█    ", "████ ", "    █", "████ "],
    '6': [" ███ ", "█    ", "████ ", "█   █", " ███ "],
    '7': ["█████", "   █ ", "  █  ", " █   ", "█    "],
    '8': [" ███ ", "█   █", " ███ ", "█   █", " ███ "],
    '9': [" ███ ", "█   █", " ████", "    █", " ███ "],
    '!': [" █ ", " █ ", " █ ", "   ", " █ "],
    '?': [" ███ ", "█   █", "   █ ", "     ", "  █  "],
    '.': ["   ", "   ", "   ", "   ", " █ "],
    ',': ["   ", "   ", "   ", " █ ", "█  "],
    ':': ["   ", " █ ", "   ", " █ ", "   "],
    ';': ["   ", " █ ", "   ", " █ ", "█  "],
    "'": [" █ ", " █ ", "   ", "   ", "   "],
    '"': ["█ █ ", "█ █ ", "   ", "   ", "   "],
    '(': ["  █ ", " █  ", "█   ", " █  ", "  █ "],
    ')': [" █  ", "  █ ", "   █", "  █ ", " █  "],
    '[': [" ██ ", "█   ", "█   ", "█   ", " ██ "],
    ']': [" ██ ", "   █", "   █", "   █", " ██ "],
    '{': ["  ██", " █  ", "██  ", " █  ", "  ██"],
    '}': ["██  ", "  █ ", "  ██", "  █ ", "██  "],
    '<': ["   █", " █  ", "█   ", " █  ", "   █"],
    '>': ["█   ", "  █ ", "   █", "  █ ", "█   "],
    '/': ["    █", "   █ ", "  █  ", " █   ", "█    "],
    '\\': ["█    ", " █   ", "  █  ", "   █ ", "    █"],
    '|': [" █ ", " █ ", " █ ", " █ ", " █ "],
    '-': ["     ", "     ", " ███ ", "     ", "     "],
    '_': ["     ", "     ", "     ", "     ", "█████"],
    '=': ["     ", " ███ ", "     ", " ███ ", "     "],
    '+': ["     ", "  █  ", " ███ ", "  █  ", "     "],
    '*': ["     ", " █ █ ", "  █  ", " █ █ ", "     "],
    '#': [" █ █ ", "█████", " █ █ ", "█████", " █ █ "],
    '$': ["  ██", "█ █ █", "██  ", "█ █ █", " ██  "],
    '%': ["█   █", "   █ ", "  █  ", " █   ", "█   █"],
    '^': [" █  ", "█ █ ", "    ", "    ", "    "],
    '&': ["  █  ", " █   ", "  █  ", "█ █ █", " ███ "],
    '@': [" ███ ", "█   █", "█ ██ ", "█    ", " ███ "],
    ' ': [" ", " ", " ", " ", " "]
},
    "serif": {
    'A': ["  ▲  ", " ▲ ▲ ", "▲▲▲▲▲", "▲   ▲", "▲   ▲"],
    'B': ["▲▲▲  ", "▲  ▲ ", "▲▲▲  ", "▲  ▲ ", "▲▲▲  "],
    'C': [" ▲▲▲ ", "▲    ", "▲    ", "▲    ", " ▲▲▲ "],
    'D': ["▲▲▲  ", "▲  ▲ ", "▲  ▲ ", "▲  ▲ ", "▲▲▲  "],
    'E': ["▲▲▲▲▲", "▲    ", "▲▲▲▲ ", "▲    ", "▲▲▲▲▲"],
    'F': ["▲▲▲▲▲", "▲    ", "▲▲▲▲ ", "▲    ", "▲    "],
    'G': [" ▲▲▲ ", "▲    ", "▲  ▲▲", "▲   ▲", " ▲▲▲ "],
    'H': ["▲   ▲", "▲   ▲", "▲▲▲▲▲", "▲   ▲", "▲   ▲"],
    'I': ["▲▲▲▲▲", "  ▲  ", "  ▲  ", "  ▲  ", "▲▲▲▲▲"],
    'J': ["  ▲▲▲", "    ▲", "    ▲", "▲   ▲", " ▲▲▲ "],
    'K': ["▲  ▲ ", "▲ ▲  ", "▲▲▲  ", "▲ ▲  ", "▲  ▲ "],
    'L': ["▲    ", "▲    ", "▲    ", "▲    ", "▲▲▲▲▲"],
    'M': ["▲   ▲", "▲▲ ▲▲", "▲ ▲ ▲", "▲   ▲", "▲   ▲"],
    'N': ["▲   ▲", "▲▲  ▲", "▲ ▲ ▲", "▲  ▲▲", "▲   ▲"],
    'O': [" ▲▲▲ ", "▲   ▲", "▲   ▲", "▲   ▲", " ▲▲▲ "],
    'P': ["▲▲▲▲ ", "▲   ▲", "▲▲▲▲ ", "▲    ", "▲    "],
    'Q': [" ▲▲▲ ", "▲   ▲", "▲ ▲ ▲", "▲  ▲▲", " ▲▲▲▲"],
    'R': ["▲▲▲▲ ", "▲   ▲", "▲▲▲▲ ", "▲ ▲  ", "▲  ▲ "],
    'S': [" ▲▲▲▲", "▲    ", " ▲▲▲ ", "    ▲", "▲▲▲▲ "],
    'T': ["▲▲▲▲▲", "  ▲  ", "  ▲  ", "  ▲  ", "  ▲  "],
    'U': ["▲   ▲", "▲   ▲", "▲   ▲", "▲   ▲", " ▲▲▲ "],
    'V': ["▲   ▲", "▲   ▲", "▲   ▲", " ▲ ▲ ", "  ▲  "],
    'W': ["▲   ▲", "▲   ▲", "▲ ▲ ▲", "▲▲ ▲▲", "▲   ▲"],
    'X': ["▲   ▲", " ▲ ▲ ", "  ▲  ", " ▲ ▲ ", "▲   ▲"],
    'Y': ["▲   ▲", " ▲ ▲ ", "  ▲  ", "  ▲  ", "  ▲  "],
    'Z': ["▲▲▲▲▲", "   ▲ ", "  ▲  ", " ▲   ", "▲▲▲▲▲"],
    ' ': ["     ", "     ", "     ", "     ", "     "],
    'a': ["     ", " ▲▲  ", "▲  ▲ ", "▲▲▲▲ ", "▲  ▲ "],
    'b': ["▲    ", "▲    ", "▲▲▲▲ ", "▲   ▲", "▲▲▲▲ "],
    'c': ["     ", " ▲▲▲ ", "▲    ", "▲    ", " ▲▲▲ "],
    'd': ["    ▲", "    ▲", " ▲▲▲▲", "▲   ▲", " ▲▲▲▲"],
    'e': ["     ", " ▲▲▲ ", "▲▲▲▲ ", "▲    ", " ▲▲▲ "],
    'f': [" ▲▲▲ ", "▲    ", "▲▲▲  ", "▲    ", "▲    "],
    'g': ["     ", " ▲▲▲▲", "▲   ▲", " ▲▲▲▲", "    ▲", " ▲▲▲ "],
    'h': ["▲    ", "▲    ", "▲▲▲▲ ", "▲   ▲", "▲   ▲"],
    'i': ["▲", " ", "▲", "▲", "▲"],
    'j': ["  ▲ ", "    ", "  ▲ ", "  ▲ ", "▲ ▲ ", " ▲▲ "],
    'k': ["▲   ", "▲  ▲", "▲▲▲ ", "▲  ▲", "▲   ▲"],
    'l': ["▲ ", "▲ ", "▲ ", "▲ ", "▲ "],
    'm': ["      ", "▲ ▲ ▲", "▲ ▲ ▲", "▲ ▲ ▲", "▲ ▲ ▲"],
    'n': ["     ", "▲▲▲▲ ", "▲   ▲", "▲   ▲", "▲   ▲"],
    'o': ["     ", " ▲▲▲ ", "▲   ▲", "▲   ▲", " ▲▲▲ "],
    'p': ["     ", "▲▲▲▲ ", "▲   ▲", "▲▲▲▲ ", "▲    ", "▲    "],
    'q': ["     ", " ▲▲▲▲", "▲   ▲", " ▲▲▲▲", "    ▲", "    ▲"],
    'r': ["     ", "▲ ▲▲ ", "▲▲   ", "▲    ", "▲    "],
    's': ["    ", " ▲▲▲", "▲   ", " ▲▲▲", "   ▲", "▲▲▲ "],
    't': [" ▲  ", "▲▲▲ ", " ▲  ", " ▲  ", " ▲▲ "],
    'u': ["     ", "▲   ▲", "▲   ▲", "▲   ▲", " ▲▲▲ "],
    'v': ["     ", "▲   ▲", "▲   ▲", " ▲ ▲ ", "  ▲  "],
    'w': ["      ", "▲   ▲", "▲ ▲ ▲", "▲▲ ▲▲", "▲   ▲"],
    'x': ["     ", "▲   ▲", " ▲ ▲ ", "  ▲  ", "▲   ▲"],
    'y': ["     ", "▲   ▲", " ▲ ▲ ", "  ▲  ", " ▲   ", "▲    "],
    'z': ["    ", "▲▲▲▲", "  ▲ ", " ▲  ", "▲▲▲▲"],
    '0': [" ▲▲▲ ", "▲   ▲", "▲   ▲", "▲   ▲", " ▲▲▲ "],
    '1': ["  ▲  ", " ▲▲  ", "  ▲  ", "  ▲  ", "▲▲▲▲▲"],
    '2': [" ▲▲▲ ", "▲   ▲", "   ▲ ", " ▲   ", "▲▲▲▲▲"],
    '3': ["▲▲▲▲ ", "    ▲", " ▲▲▲ ", "    ▲", "▲▲▲▲ "],
    '4': ["▲   ▲", "▲   ▲", "▲▲▲▲▲", "    ▲", "    ▲"],
    '5': ["▲▲▲▲▲", "▲    ", "▲▲▲▲ ", "    ▲", "▲▲▲▲ "],
    '6': [" ▲▲▲ ", "▲    ", "▲▲▲▲ ", "▲   ▲", " ▲▲▲ "],
    '7': ["▲▲▲▲▲", "   ▲ ", "  ▲  ", " ▲   ", "▲    "],
    '8': [" ▲▲▲ ", "▲   ▲", " ▲▲▲ ", "▲   ▲", " ▲▲▲ "],
    '9': [" ▲▲▲ ", "▲   ▲", " ▲▲▲▲", "    ▲", " ▲▲▲ "],
    '!': [" ▲ ", " ▲ ", " ▲ ", "   ", " ▲ "],
    '?': [" ▲▲▲ ", "▲   ▲", "   ▲ ", "     ", "  ▲  "],
    '.': ["   ", "   ", "   ", "   ", " ▲ "],
    ',': ["   ", "   ", "   ", " ▲ ", "▲  "],
    ':': ["   ", " ▲ ", "   ", " ▲ ", "   "],
    ';': ["   ", " ▲ ", "   ", " ▲ ", "▲  "],
    "'": [" ▲ ", " ▲ ", "   ", "   ", "   "],
    '"': ["▲ ▲ ", "▲ ▲ ", "   ", "   ", "   "],
    '(': ["  ▲ ", " ▲  ", "▲   ", " ▲  ", "  ▲ "],
    ')': [" ▲  ", "  ▲ ", "   ▲", "  ▲ ", " ▲  "],
    '[': [" ▲▲ ", "▲   ", "▲   ", "▲   ", " ▲▲ "],
    ']': [" ▲▲ ", "   ▲", "   ▲", "   ▲", " ▲▲ "],
    '{': ["  ▲▲", " ▲  ", "▲▲  ", " ▲  ", "  ▲▲"],
    '}': ["▲▲  ", "  ▲ ", "  ▲▲", "  ▲ ", "▲▲  "],
    '<': ["   ▲", " ▲  ", "▲   ", " ▲  ", "   ▲"],
    '>': ["▲   ", "  ▲ ", "   ▲", "  ▲ ", "▲   "],
    '/': ["    ▲", "   ▲ ", "  ▲  ", " ▲   ", "▲    "],
    '\\': ["▲    ", " ▲   ", "  ▲  ", "   ▲ ", "    ▲"],
    '|': [" ▲ ", " ▲ ", " ▲ ", " ▲ ", " ▲ "],
    '-': ["     ", "     ", " ▲▲▲ ", "     ", "     "],
    '_': ["     ", "     ", "     ", "     ", "▲▲▲▲▲"],
    '=': ["     ", " ▲▲▲ ", "     ", " ▲▲▲ ", "     "],
    '+': ["     ", "  ▲  ", " ▲▲▲ ", "  ▲  ", "     "],
    '*': ["     ", " ▲ ▲ ", "  ▲  ", " ▲ ▲ ", "     "],
    '#': [" ▲ ▲ ", "▲▲▲▲▲", " ▲ ▲ ", "▲▲▲▲▲", " ▲ ▲ "],
    '$': ["  ▲▲", "▲ ▲ ▲", "▲▲  ", "▲ ▲ ▲", " ▲▲  "],
    '%': ["▲   ▲", "   ▲ ", "  ▲  ", " ▲   ", "▲   ▲"],
    '^': [" ▲  ", "▲ ▲ ", "    ", "    ", "    "],
    '&': ["  ▲  ", " ▲   ", "  ▲  ", "▲ ▲ ▲", " ▲▲▲ "],
    '@': [" ▲▲▲ ", "▲   ▲", "▲ ▲▲ ", "▲    ", " ▲▲▲ "],
    ' ': [" ", " ", " ", " ", " "]
    
},
    "serif_font" : {
    'A': ["  ___ ", " / _ \\", "/ /_\\ \\", "|  _  |", "|_| |_|"],
    'B': ["____  ", "| __ ) ", "|  _ \\", "| |_) |", "|____/ "],
    'C': [" _____", "/  __ \\", "| /  \\/", "| |    ", "\\_____/"],
    'D': ["____  ", "|  _ \\", "| | | |", "| |_| |", "|____/ "],
    'E': [" _____", "| ____|", "|  _|  ", "| |___ ", "|_____|"],
    'F': ["______", "|  ___|", "| |_   ", "|  _|  ", "|_|    "],
    'G': [" _____", "|  __ \\", "| |  \\/", "| | __ ", "| |_\\ \\", " \\____/"],
    'H': [" _   _ ", "| | | |", "| |_| |", "|  _  |", "|_| |_|"],
    'I': [" ___ ", "|_ _|", " | | ", " | | ", "|___|"],
    'J': ["    _ ", "   | |", "   | |", "/\\_| |", "\\___/ "],
    'K': [" _   __", "| | / /", "| |/ / ", "|    \\ ", "|_|\\_\\ "],
    'L': [" _     ", "| |    ", "| |    ", "| |___ ", "|_____|"],
    'M': ["___  ___", "|  \\/  |", "| .  . |", "| |\\/| |", "|_|  |_|"],
    'N': [" _   _ ", "| \\ | |", "|  \\| |", "| . ` |", "|_|\\_|"],
    'O': [" _____ ", "|  _  |", "| | | |", "| |_| |", "\\_____/"],
    'P': ["____  ", "|  _ \\", "| |_| |", "|  __/", "|_|   "],
    'Q': [" _____ ", "|  _  |", "| | | |", "| |/ / ", "|___\\_\\"],
    'R': ["____  ", "|  _ \\", "| |_| |", "|    / ", "|_|\\_\\"],
    'S': [" ____ ", "/ ___|", "\\___ \\", " ___) |", "|____/ "],
    'T': [" _____", "|_   _|", "  | |  ", "  | |  ", "  |_|  "],
    'U': [" _   _ ", "| | | |", "| | | |", "| |_| |", "\\_____/"],
    'V': ["__     __", "\\ \\   / /", " \\ \\ / / ", "  \\ V /  ", "   \\_/   "],
    'W': ["__        __", "\\ \\      / /", " \\ \\ /\\ / / ", "  \\ V  V /  ", "   \\_/\\_/   "],
    'X': ["__  __", "\\ \\/ /", " >  < ", "/_/\\_\\", "      "],
    'Y': ["__   __", "\\ \\ / /", " \\ V / ", "  | |  ", "  |_|  "],
    'Z': ["______", "|__  /", "  / / ", " / /_ ", "/____|"],    
    'a': ["  ___ ", " / _ \\", "/ /_\\ \\", "|  _  |", "|_| |_|"],
    'b': ["____  ", "| __ ) ", "|  _ \\", "| |_) |", "|____/ "],
    'c': [" _____", "/  __ \\", "| /  \\/", "| |    ", "\\_____/"],
    'd': ["____  ", "|  _ \\", "| | | |", "| |_| |", "|____/ "],
    'e': [" _____", "| ____|", "|  _|  ", "| |___ ", "|_____|"],
    'f': ["______", "|  ___|", "| |_   ", "|  _|  ", "|_|    "],
    'g': [" _____", "|  __ \\", "| |  \\/", "| | __ ", "| |_\\ \\", " \\____/"],
    'h': [" _   _ ", "| | | |", "| |_| |", "|  _  |", "|_| |_|"],
    'i': [" ___ ", "|_ _|", " | | ", " | | ", "|___|"],
    'j': ["    _ ", "   | |", "   | |", "/\\_| |", "\\___/ "],
    'k': [" _   __", "| | / /", "| |/ / ", "|    \\ ", "|_|\\_\\ "],
    'l': [" _     ", "| |    ", "| |    ", "| |___ ", "|_____|"],
    'm': ["___  ___", "|  \\/  |", "| .  . |", "| |\\/| |", "|_|  |_|"],
    'n': [" _   _ ", "| \\ | |", "|  \\| |", "| . ` |", "|_|\\_|"],
    'o': [" _____ ", "|  _  |", "| | | |", "| |_| |", "\\_____/"],
    'p': ["____  ", "|  _ \\", "| |_| |", "|  __/", "|_|   "],
    'q': [" _____ ", "|  _  |", "| | | |", "| |/ / ", "|___\\_\\"],
    'r': ["____  ", "|  _ \\", "| |_| |", "|    / ", "|_|\\_\\"],
    's': [" ____ ", "/ ___|", "\\___ \\", " ___) |", "|____/ "],
    't': [" _____", "|_   _|", "  | |  ", "  | |  ", "  |_|  "],
    'u': [" _   _ ", "| | | |", "| | | |", "| |_| |", "\\_____/"],
    'v': ["__     __", "\\ \\   / /", " \\ \\ / / ", "  \\ V /  ", "   \\_/   "],
    'w': ["__        __", "\\ \\      / /", " \\ \\ /\\ / / ", "  \\ V  V /  ", "   \\_/\\_/   "],
    'x': ["__  __", "\\ \\/ /", " >  < ", "/_/\\_\\", "      "],
    'y': ["__   __", "\\ \\ / /", " \\ V / ", "  | |  ", "  |_|  "],
    'z': ["______", "|__  /", "  / / ", " / /_ ", "/____|"],
    '0': [" _____ ", "|  _  |", "| | | |", "| |_| |", "|_____|"],
    '1': [" __ ", "/_ |", " | |", " | |", " |_|"],
    '2': [" ____  ", "|___ \\ ", "  __) |", " / __/ ", "|_____|"],
    '3': [" _____", "|___ /", "  |_ \\", " ___) |", "|____/ "],
    '4': [" _  _  ", "| || | ", "| || |_","|__   _|", "   |_|  "],
    '5': [" ____ ", "| ___|", "|___ \\", " ___) |", "|____/ "],
    '6': ["  __  ", " / /_ ", "| '_ \\", "| (_) |", " \\___/ "],
    '7': [" _____", "|___  |", "   / / ", "  / /  ", " /_/   "],
    '8': ["  ___  ", " ( _ ) ", " / _ \\", "| (_) |", " \\___/ "],
    '9': ["  ___ ", " / _ \\", "| (_) |", " \\__, |", "   /_/ "],
    '!': [" _ ", "| |", "| |", "|_|", "(_)"],
    '@': [" _____ ", "|  _  |", "| |/' |", "|  /| |", "\\ |_/ /", " \\___/ "],
    '#': ["  _  _   ", " | || |  ", "/ __) |__","\\__ \\ '_ \\", " |___/_.__/"],
    '$': ["  _  ", " | | ", "/ __)", "\\__ \\", "(___/"],
    '%': [" _   __", "(_) / /", "   / / ", "  / /_ ", " /_/(_)"],
    '^': [" /\\ ", "|/\\|", "    ", "    ", "    "],
    '&': ["  ___   ", " ( _ )  ", " / _ \\/\\", "| (_>  <", " \\___/\\/"],
    '*': ["     ", "_/\\_", "\\  /", "/_\\_", "     "],
    '(': ["  __", " / /", "| | ", "| | ", " \\_\\"],
    ')': ["__  ", "\\ \\ ", " | |", " | |", "/_/ "],
    '_': ["       ", "       ", "       ", "       ", "_______"],
    '+': ["       ", "   |   ", " --+-- ", "   |   ", "       "],
    '-': ["      ", "      ", " ---- ", "      ", "      "],
    '=': ["       ", " _____ ", "|_____|", "       ", "       "],
    '[': [" ___", "|  |", "|  |", "|  |", "|__|"],
    ']': ["___ ", "|  |", "|  |", "|  |", "|__|"],
    '{': ["  __", " / /", "< < ", " \\_\\", "    "],
    '}': ["__  ", "\\ \\ ", " > >", "/_/ ", "    "],
    '|': [" | ", " | ", " | ", " | ", " | "],
    ';': [" ; ", " ; ", "   ", " ; ", ";  "],
    ':': ["   ", " o ", "   ", " o ", "   "],
    "'": [" _ ", "( )", "|/ ", "   ", "   "],
    '"': ["_ _", "( )", "|/ ", "   ", "   "],
    ',': ["   ", "   ", "   ", " _ ", "( )"],
    '.': ["   ", "   ", "   ", " _ ", "(_)"],
    '<': ["   __", "  / /", " < < ", "  \\_\\", "     "],
    '>': ["__   ", "\\ \\  ", " > > ", "/_/  ", "     "],
    '/': ["    /", "   / ", "  /  ", " /   ", "/    "],
    '?': [" ___ ", "|__ \\", "  / /", " |_| ", " (_) "],
    '`': [" _ ", "( )", " \\|", "   ", "   "],
    ' ': [" ", " ", " ", " ", " "]
}

    # Add more custom styles if you want
}

def blockfont(text, style="standard", max_length=20):

    if style in ASCII_STYLES:
        style_dict = ASCII_STYLES[style]

        # Wrap the text with boundaries 
        lines_of_text = textwrap.wrap(text, width=max_length)

        
        block_lines = []

        for wrapped_text in lines_of_text:
            lines = ["" for _ in range(5)]  

            for char in wrapped_text:
                pattern = style_dict.get(char, ["     "] * 5)
                for i in range(5):
                    lines[i] += pattern[i] + "  "

            block_lines.append("\n".join(lines))

        
        return "\n\n".join(block_lines)

    else:
        try:
            return pyfiglet.figlet_format(text, font=style)
        except pyfiglet.FontNotFound:
            available = list(ASCII_STYLES.keys())
            return f"❌ Font '{style}' not found. Available custom styles: {', '.join(available)} or any pyfiglet font."
